@@ -1,7 +1,7 @@
 #ifndef _CLASS1_H_
 #define _CLASS1_H_
 
-#include "class2.h"
+#include "Class2.h"
 
 class Class1
 {
